#!/bin/sh

# Wrapper script for keepup2date binary.
# 
# Options:
#   -h                Informations about the options.
#   -install          This adds a cron job for the current user. 
#   -uninstall        Uninstall the cron job.
#
KBIN=/opt/kaspersky/kav4proxy/bin/kav4proxy-keepup2date
KAVUSER=kluser

#-------------------------------------------------------------------------------
usage()
{
    echo
    echo 'Usage: '$0' [options]'
    echo
    echo 'Options:'
    echo -e '  -h\t\t\tThis information'
    echo -e '  -install\t\tAdd a cron job for this script'
    echo -e '  -prompt-install\tInteractive cron job addition'
    echo -e '  -uninstall\t\tUninstall the cron job'
    echo

    exit 0
}

err()
{
    code=$1 
    shift
    echo $@ >&2
    exit $code
}

#-------------------------------------------------------------------------------
requires()
{
  local bin
  if [ $#  -lt 1 ]; then return 0; fi
  for bin in $@; do
      if [ "`which $bin`" != "false" ]; then
          continue
      else
          err 1 "Binary $bin is required but couldn't be found in path."
      fi
  done
}

#-------------------------------------------------------------------------------
kl_crontab()
{
  local file=$1
  local user=$2
  local args=""
  requires crontab

  [ $# -lt 3 ] || { shift 3; args="$@"; }

  case "`uname -s`" in
    FreeBSD|OpenBSD) crontab -u $user $file $args 2>/dev/null;;
              Linux) crontab $file -u $user $args 2>/dev/null;;
  esac
}

#-------------------------------------------------------------------------------
keepup2date_job()
{
local action=${1:-install}
local TMPFILE tmpdate

requires crontab 
requires sed

local keepup2date=`echo "$KBIN" | sed -e 's/[\/]/\\\\\//g'`;

TMPFILE=`mktemp /tmp/cron.XXXXXXXXXX` || exit 1
crontab -u $KAVUSER -l 2>/dev/null | grep -v '^#.*' > $TMPFILE 2>/dev/null

if [ "$action" = "install" ]; then
    # install
    requires grep
    if [ "`grep "$keepup2date" $TMPFILE`" != "" ] ; then
        rm -f $TMPFILE
        err 0 "keepup2date cron job already present"
    else
        mins="`date '+%M'| sed 's/^0*//'`"
        mins="$(( (${mins} + 2) % 59 ))"

        if [ "$mins" -ge 30 ] ; then
            mins2=$(( ${mins} - 30 ))
            mins="$mins2,$mins"
        else
            mins2=$(( ${mins} + 30 ))
            mins="$mins,$mins2"
        fi
        echo  "$mins */1 * * * $KBIN -e" >> $TMPFILE
    fi
else
    # uninstall
    TMPFILE2=`mktemp /tmp/cron.XXXXXXXXXX` || exit 1
    sed -e "/$keepup2date/d" $TMPFILE > $TMPFILE2
    mv -f $TMPFILE2 $TMPFILE
fi
kl_crontab $TMPFILE $KAVUSER
rm -f $TMPFILE
}

#-------------------------------------------------------------------------------
interactive_install()
{
 local x
 printf "Do you want to activate regular updates? [y/N]: " 
 read x
 [ "$x" = "y" -o "$x" = "Y" ] && {
    keepup2date_job install    
  }
}

#================================================================================

while [ $# -gt 0 ]; do
    case $1 in 
        -h|--help) 
            usage
            ;;
        -install) 
            ACTION=install
            shift
            ;;
        -prompt-install)
            ACTION=intinstall
            shift
            ;;

        -uninstall) 
          ACTION=uninstall
          shift
          ;;

        *) 
            echo "ERROR: Unknown option '$1'"
            usage
            ;;
    esac
done

case $ACTION in
    install|uninstall)
        keepup2date_job $ACTION
        ;;

    intinstall)
        interactive_install
        ;;

    *)
        usage
        ;;
esac

exit $?
